@@ -21,8 +21,11 @@
 #'   Possible options are: "clone" - copy filters from last step,
 #'   "configure" - opening modal and allow to chose filters from available filters.
 #' @param ... Extra parameters passed to selected cohort methods.
-#'   Now only \link{code} arguments are supported.
-#' @return No return value, used for side effect which is running a Shiny application.
+#'   Currently unused.
+#' @param run_app If 'TRUE' the application will run using \link[shiny]{runApp},
+#'   otherwise \link[shiny]{shinyApp} object is returned.
+#' @return In case of `run_app=TRUE` no return value, used for side effect which is running a Shiny application.
+#'   Otherwise \link[shiny]{shinyApp} object.
 #'
 #' @examples
 #' if (interactive()) {
@@ -36,12 +39,16 @@
 #' @export
 demo_app <- function(
   steps = TRUE, stats = c("pre", "post"), run_button = "none", feedback = TRUE, state = TRUE,
-  bootstrap = 3, enable_bookmarking = TRUE, code = TRUE, attrition = TRUE, show_help = TRUE,
-  new_step = c("clone", "configure"), ...) {
+  bootstrap = 5, enable_bookmarking = TRUE, code = TRUE, attrition = TRUE, show_help = TRUE,
+  new_step = c("clone", "configure"), ..., run_app = TRUE) {
 
   if (is.logical(run_button)) {
     lifecycle::deprecate_stop("0.2.0", "shinyCohorBuilder::demo_app(arg = 'must be a scalar character')")
   }
+  run_method <- shiny::shinyApp
+  if (isTRUE(run_app)) {
+    run_method <- function(ui, server) shiny::runApp(list(ui = ui, server = server), ...)
+  }
 
   old_opts <- options()
   on.exit(options(old_opts))
@@ -82,11 +89,11 @@ demo_app <- function(
         biom3 = c("A", "B", "A", "B", "A", "B", "A", "B", "A", "B", "A", "B", "A", "B", "B")
       ),
       therapy = data.frame(
-        patient_id = c(1:15, 1:5),
-        line_id = c(rep(1, 15), rep(2, 5)),
+        patient_id = c(1:15, 1:5, 1:3),
+        line_id = c(rep(1, 15), rep(2, 5), rep(3, 3)),
         treatment = c(
-          "Atezo", "Chemo", "Nebul", "Atezo", "Chemo", "Nebul", "Atezo", "Chemo", "Atezo", "Atezo",
-          "Nebul", "Atezo", "Chemo", "Atezo", "Atezo", "Nebul", "Atezo", "Chemo", "Nebul", "Atezo"
+          "Atezo", "Chemo", "Nebul", "Atezo", "Chemo", "Nebul", "Atezo", "Chemo", "Atezo", "Atezo", "Atezo", "Nebul",
+          "Nebul", "Atezo", "Chemo", "Atezo", "Atezo", "Nebul", "Atezo", "Chemo", "Nebul", "Atezo", "Atezo"
         )
       ) %>%
         dplyr::mutate(id = paste(patient_id, line_id, sep = "_")) %>%
@@ -94,9 +101,9 @@ demo_app <- function(
     )
   )
 
-  shiny::runApp(list(
+  run_method(
     ui = function(req) {
-      shiny::fluidPage(
+      bslib::page_fluid(
         theme = bslib::bs_theme(version = bootstrap),
         if (isTRUE(enable_bookmarking)) shiny::bookmarkButton() else NULL,
         shiny::radioButtons("dataset", "Source", c("No binding keys" = "01", "Binding keys" = "02")),
@@ -126,9 +133,20 @@ demo_app <- function(
         description = "The Age field is an length of time that a person has lived or a thing has existed.",
         feedback = FALSE
       )
-      treatment_filter <- cohortBuilder::filter(
-        type = "discrete", id = "treatment", name = "Treatment", variable = "treatment",
-        dataset = "therapy", value = "Atezo", gui_input = "vs", stats = "post"
+      treatment_filter = list(
+        "01" = cohortBuilder::filter(
+          type = "discrete", id = "treatment", name = "Treatment", variable = "treatment",
+          dataset = "therapy", value = "Atezo", gui_input = "vs", stats = "post"
+        ),
+        "02" = cohortBuilder::filter(
+          type = "query", id = "treatment", name = "Treatment",
+          variables = c("treatment", "line_id"), dataset = "therapy",
+          value = queryBuilder::queryGroup(
+            condition = "AND",
+            queryBuilder::queryRule("treatment", "equal", "Atezo"),
+            queryBuilder::queryRule("line_id", "less_or_equal", 3)
+          )
+        )
       )
       visit_filter <- cohortBuilder::filter(
         "date_range", name = "Visit", variable = "visit", dataset = "patients"
@@ -165,7 +183,7 @@ demo_app <- function(
         available_filters = list(
           gender_filter,
           age_filter,
-          treatment_filter
+          treatment_filter[["01"]]
         ),
         primary_keys = cohortBuilder::primary_keys(
           cohortBuilder::data_key("patients", "id"),
@@ -190,13 +208,14 @@ demo_app <- function(
         )
         coh$restore(url_state)
       } else {
+
         coh <- cohortBuilder::cohort(
           patients_source,
           cohortBuilder::step(
             group_filter,
             gender_filter,
             age_filter,
-            treatment_filter,
+            treatment_filter[["01"]],
             visit_filter,
             biom_filter
           )
@@ -214,7 +233,7 @@ demo_app <- function(
           available_filters = list(
             gender_filter,
             age_filter,
-            treatment_filter
+            treatment_filter[[input$dataset]]
           ),
           value_mappings = list(
             gender_mapping = gender_mapping
@@ -237,7 +256,7 @@ demo_app <- function(
               group_filter,
               gender_filter,
               age_filter,
-              treatment_filter,
+              treatment_filter[[input$dataset]],
               visit_filter
             )
           )
@@ -256,7 +275,7 @@ demo_app <- function(
         print(returned_data())
       })
     }
-  ))
+  )
 }
 
 # todo Make queue of actions and with delay execute them.
@@ -284,7 +303,7 @@ demo_app <- function(
 gui <- function(
   cohort,
   steps = TRUE, stats = c("pre", "post"), run_button = "none", feedback = TRUE, state = TRUE,
-  bootstrap = 3, enable_bookmarking = TRUE, code = TRUE, attrition = TRUE, show_help = TRUE,
+  bootstrap = 5, enable_bookmarking = TRUE, code = TRUE, attrition = TRUE, show_help = TRUE,
   new_step = c("clone", "configure")) {
 
   if (is.logical(run_button)) {
@@ -301,8 +320,8 @@ gui <- function(
 
   shiny::runApp(list(
     ui = function(req) {
-      shiny::fluidPage(
-        shiny::tags$style("body {font-size: 12px;};"),
+      bslib::page_fluid(
+        theme = bslib::bs_theme(version = bootstrap),
         cb_ui(
           id = "coh", style = "width: 300px; float: left;",
           steps = steps, state = state, code = code, attrition = attrition,
